Simple test
------------

Ensure your device works with this simple test.

.. literalinclude:: ../examples/dps310_simpletest.py
    :caption: examples/dps310_simpletest.py
    :linenos:

Lower Power Weather Station
---------------------------

Example showing how to configure the sensor for continuous measurement with rates,
sampling counts and mode optimized for low power

.. literalinclude:: ../examples/dps310_low_power_weather_station.py
    :caption: examples/dps310_low_power_weather_station.py
    :linenos:
